; ©2011 Arun S K.
; https://www.skipser.com/p/2/p/how-to-watermark-photos-using-gimp.html

; Add an external watermark image in a corner or image
; MrQ: 23/01/2022 update for Gimp-2.10/2.99.8

(cond ((not (defined? 'gimp-image-get-width)) (define gimp-image-get-width gimp-image-width)))
(cond ((not (defined? 'gimp-image-get-height)) (define gimp-image-get-height gimp-image-height)))
(cond ((not (defined? 'gimp-drawable-get-width)) (define gimp-drawable-get-width gimp-drawable-width)))
(cond ((not (defined? 'gimp-drawable-get-height)) (define gimp-drawable-get-height gimp-drawable-height)))


(define (image-watermark-on-corner image layer photo location opacity offsetx offsety keep-layers)

(gimp-image-undo-group-start image)
;Open file
(set! layer ( car (gimp-file-load-layer 0 image photo)))

(let*
  ( (imagewid (car (gimp-image-get-width image)))
    (imagehgt (car (gimp-image-get-height image)))

    (lwid  (car (gimp-drawable-get-width  layer)))
    (lhgt (car (gimp-drawable-get-height layer)))

;   Set the X and Y locations offset by 10 pixels from the chosen corner
    (xlayer
         (cond ((= (fmod location 2) 0) offsetx)
               ((= (fmod location 2) 1) (- (- imagewid lwid) offsetx))))

    (ylayer
         (cond ((<= location 1) (- (- imagehgt lhgt) offsety))
               ;((>= location 2) 0)))    bug fix MrQ
			   ((>= location 2) offsety)))

  )

; Set the offset
  (gimp-layer-set-offsets layer xlayer ylayer)

;    Add layer
  ;(gimp-image-add-layer image layer 0) bug fix MrQ
  (gimp-image-insert-layer image layer 0 0)
; Set the opacity of the watermark layer
  (gimp-layer-set-opacity layer opacity)
  
   (if (= keep-layers FALSE)                            
      (gimp-image-merge-down image layer 2) 
   )
)

 (gimp-image-undo-group-end image) 
(gimp-displays-flush)

)

(script-fu-register "image-watermark-on-corner"
	"Image Watermark on corner..."
	"ImageWatermark"
	"Arun S K"
	"GPL"
	"2011/22"
	"RGB*, GRAY*"
	SF-IMAGE      "Image" 0
	SF-DRAWABLE   "Drawable" 0
	SF-FILENAME   "Watermark Photo" "Your Image"
	SF-OPTION     "Location" '("Lower left" "Lower right" "Upper left" "Upper right")
	SF-ADJUSTMENT "Opacity" '(60 0 100 1 10 0 1)
	SF-ADJUSTMENT "OffsetX" '(10 0 5000 1 10 0 1)
	SF-ADJUSTMENT "OffsetY" '(10 0 5000 1 10 0 1)
	SF-TOGGLE     "Keep the Layers"   FALSE
)

(script-fu-menu-register "image-watermark-on-corner" "<Image>/Filters/Watermark/")

